/**
 * COPYRIGHT 2019 Flirc, Inc. All rights reserved.
 *
 * This copyright notice is Copyright Management Information under 17 USC 1202
 * and is included to protect this work and deter copyright infringement.
 * Removal or alteration of this Copyright Management Information without
 * the express written permission of Flirc, Inc. is prohibited, and any
 * such unauthorized removal or alteration will be a violation of federal law.
 *
 * @file
 * @brief   Flirc Library functions
 */

#include <sys/types.h>
#include <stdio.h>
#include <errno.h>
#include <stdlib.h>

#include <logging.h>

#ifndef I__FILE_OPTS_H__
	#define I__FILE_OPTS_H__

/**
 * file_to_buf() converts a file pointer to a buffer
 *
 * @param loc 	- pointer to file location to open
 * @param **buf - allocation address of buffer passed
 * @param *ops 	- passed ops to fopen, "rb", etc
 *
 * @return      ssize_t      - size of buf, or negative error
 */
ssize_t file_to_buf(const char *loc, unsigned char **buf, const char *ops);

/**
 * buf_to_file() saves a buffer to a file
 *
 * @param loc  - location of file to be saved
 * @param *buf - bufer that will be written to file
 * @param len  - length of buffer
 * @param *ops 	- passed ops to fopen, "rb", etc
 *
 * @return ssize_t - bytes written, or negative on error
 */
ssize_t buf_to_file(const char *loc, unsigned char *buf,
		size_t len, const char *ops);

/**
 * fgetline() gets a line from a file pointer
 *
 * @param fp  	- file pointer
 * @param *buf  - buffer to put line in
 * @param bufsz - max size of the buffer
 *
 * @return ssize_t - size of line, negative on EOF
 */
ssize_t fgetline(FILE *fp, char *buf, size_t bufsz);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* I__FILE_OPTS_H__ */
